@@ -1,5 +1,10 @@
 //! Macros for poem-openapi
 
+#![doc(html_favicon_url = "https://poem.rs/assets/favicon.ico")]
+#![doc(html_logo_url = "https://poem.rs/assets/logo.png")]
+#![forbid(unsafe_code)]
+#![deny(private_in_public, unreachable_pub)]
+
 #[macro_use]
 mod validators;
 
